PyBaccarat: pybaccarat.baccarat Namespace Reference

PyBaccarat visit the ministry of silly walks

Classes
pybaccarat.baccarat Namespace Reference

This module is collection of classes used with playing the game Baccarat. More...

## Classes
class | Game
| This class plays a game of Baccarat. More...
class | Hand
| This class represents a hand in the game Baccarat. More...
class | Scoreboard
| TBD board0 = "big road" board1 = "big eye boy" board2 = "small road" board3 = "cockroach pig". More...
class | Ties
| This class tracks tie results. More...

## Detailed Description

This module is collection of classes used with playing the game Baccarat.

Classes:

- Hand
- Scoreboard
- Ties
- Game

Author
  fulkg.nosp@m.l@gm.nosp@m.ail.c.nosp@m.om

Version
  0.13